@@ -2,6 +2,11 @@ require 'pp'
 require 'mkmf'
 
 
+if ENV['MAINTAINER_MODE']
+	$stderr.puts "Maintainer mode enabled."
+	$CFLAGS << ' -Wall' << ' -ggdb' << ' -DDEBUG'
+end
+
 if pgdir = with_config( 'pg' )
 	ENV['PATH'] = "#{pgdir}/bin" + File::PATH_SEPARATOR + ENV['PATH']
 end
@@ -21,8 +26,8 @@ dir_config 'pg'
 
 if pgconfig = ( with_config('pg-config') || with_config('pg_config') || find_executable('pg_config') )
 	$stderr.puts "Using config values from %s" % [ pgconfig ]
-	$CPPFLAGS << " -I%s" % [ `#{pgconfig} --includedir`.chomp ]
-	$LDFLAGS << " -L%s" % [ `#{pgconfig} --libdir`.chomp ]
+	$CPPFLAGS << " -I%s" % [ `"#{pgconfig}" --includedir`.chomp ]
+	$LDFLAGS << " -L%s" % [ `"#{pgconfig}" --libdir`.chomp ]
 else
 	$stderr.puts "No pg_config... trying anyway. If building fails, please try again with",
 		" --with-pg-config=/path/to/pg_config"
@@ -48,6 +53,9 @@ have_func 'lo_create'
 have_func 'pg_encoding_to_char'
 have_func 'PQsetClientEncoding'
 
+have_func 'rb_encdb_alias'
+have_func 'rb_enc_alias'
+
 $defs.push( "-DHAVE_ST_NOTIFY_EXTRA" ) if
 	have_struct_member 'struct pgNotify', 'extra', 'libpq-fe.h'
 
